import { expect } from 'chai'
import sinon from 'sinon'
import DocsSidenav from './index'
import propsSpec from './props'

testComponent(
  () => DocsSidenav,
  { sets: [], props: propsSpec },
  ({ testTagAndClass, render }) => {
    testTagAndClass('div', 'g-docs-sidenav')

    it('should render nested levels correctly', () => {
      const wrapper = render()
      const threeLevels = wrapper
        .find('ul')
        .first()
        .find('li')
        .first()
        .find('ul')
        .first()
        .find('li')
        .at(1)
        .find('ul')
        .first()
        .find('li')
        .at(1)
        .find('ul')
        .first()
        .find('li')
      expect(threeLevels.at(2).attr('class')).to.contain('active')
      expect(
        threeLevels
          .at(2)
          .find('a')
          .first()
          .attr('dangerouslySetInnerHTML').__html
      ).to.contain('AWS')
      expect(threeLevels.at(1).attr('class')).to.equal('')
      expect(
        threeLevels
          .find('a')
          .at(1)
          .attr('dangerouslySetInnerHTML').__html
      ).to.equal('AliCloud')
      expect(
        threeLevels
          .find('a')
          .first()
          .text()
      ).to.equal('Overview')
    })

    it('should call toggleNav when clicking a dir link', () => {
      const toggleNavStub = sinon.stub(DocsSidenav.prototype, 'toggleNav')
      const wrapper = render()
      const dir = wrapper
        .find('.dir')
        .first()
        .find('a')
        .first()
      dir.simulate('click')
      expect(toggleNavStub).to.have.been.calledOnce
    })

    it('should call toggleMenu when clicking a dir link', () => {
      const toggleMenuStub = sinon.stub(DocsSidenav.prototype, 'toggleMenu')
      const wrapper = render()
      const dir = wrapper.find('.toggle').first()
      dir.simulate('click')
      expect(toggleMenuStub).to.have.been.calledOnce
    })
  }
)
